OakRepl

Struct OakRepl 

pub struct OakRepl<H: ReplHandler> { /* private fields */ }
The main REPL engine.

OakRepl manages the terminal interface, handles user input, and coordinates with a ReplHandler to provide language-specific functionality.

Example

use oak_repl::{HandleResult, OakRepl, ReplError, ReplHandler};

struct MyHandler;
impl ReplHandler for MyHandler {
    fn prompt(&self, _: bool) -> &str {
        "> "
    }
    fn is_complete(&self, code: &str) -> bool {
        true
    }
    fn handle_line(&mut self, line: &str) -> Result<HandleResult, ReplError> {
        println!("You typed: {}", line);
        Ok(HandleResult::Continue)
    }
}

let mut repl = OakRepl::new(MyHandler);
repl.run().expect("REPL failed");

Implementations

Source

impl<H: ReplHandler> OakRepl<H>

pub fn new(handler: H) -> Self

Creates a new OakRepl with the given handler.

pub fn run(&mut self) -> Result<(), ReplError>

Runs the REPL loop.

This method takes control of the terminal (enabling raw mode) and blocks until the user exits or an unrecoverable error occurs.